<?php
	
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 * 
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_theme_data(STYLESHEETPATH . '/style.css');
	$themename = $themename['Name'];
	$themename = preg_replace("/\W/", "", strtolower($themename) );
	
	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);
	
	// echo $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {
		
	// Background Defaults
	$background_defaults = array('color' => '#ffffff', 'image' => '', 'repeat' => 'repeat', 'position' => 'top left','attachment' => 'scroll');
	
	$bg_patterns = array("scan-lines.png" => "Scan Lines", "crossed_stripes.png" => "Crossed Stripes", "subtle_emboss.png" => "Cross Stripes Small",
						 "zig_zag_diagonal.png" => "Zig Zag Diagonal", "zig_zag_horizontal.png" => "Zig Zag Horizontal", "zig_zag_vertical.png" => "Zig Zag Vertical", 
						 "left_strip.png" => "Left Strip", "right_strip.png" => "Right Strip", "horizontal_strip.png" => "Horizontal Strip", "vertical_strip.png" => "Vertical Strip", 
						 "small_dots.png" => "Small Dots", "grid.png" => "Grid",
						 "subtle_freckles.png" => "Subtle Freckles",
						 "white_texture.png" => "White Texture", "brushed_alu.png" => "Brushed Aluminium", "little_pluses.png" => "Little Pluses", 
						 "subtle_orange_emboss.png" => "Subtle Orange Emboss");
	
	
	// Pull all the categories into an array
	$options_categories = array();  
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = __( 'Select a page:', 'onioneye' );
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_stylesheet_directory_uri() . '/images/admin/';
		
	$options = array();
	
	
	
	/*-----------------------------------------------------------------------------------*/
	/* General Settings */
	/*-----------------------------------------------------------------------------------*/
		
	$options[] = array( "name" => __("General Setting", 'onioneye'),
						"type" => "heading");
						
	$options[] = array( "name" => __("لوگوی دلخواه", 'onioneye'),
						"desc" => __("یک لوگو برای پوسته خود بارگذاری کنید. اگر این قسمت را خالی رها کنید از عنوان سایت شما استفاده خواهد شد " . 
									 "", 'onioneye'),
						"id" => "custom_logo",
						"type" => "upload");
	
	$options[] = array( "name" => __("لوگوی پانوشت دلخواه", 'onioneye'),
						"desc" => __("یک لوگو، ترجیحا یک نسخه کوچکتر از لوگوی اصلی، برای نمایش در پانوشت بارگذاری کنید. " .
						             "اگر لوگوی پانوشت نمی‌خواهید این قسمت را خالی رها کنید.", 'onioneye'),
						"id" => "custom_footer_logo",
						"type" => "upload");
						
	$options[] = array( "name" => __("Favicon دلخواه", 'onioneye'),
						"desc" => __("یک تصویر 16px x 16px یا 32px x 32px PNG/GIF/ICO برای قرار گرفتن به عنوان favicon شما بارگذاری کنید. " . 
								 	 "favicon آیکونی است که در کنار نوار آدرس مرورگر شما نمایش داده می‌شود.", 'onioneye'),
						"id" => "custom_favicon",
						"type" => "upload");
						
	$options[] = array( "name" => __("متن دلخواه سربرگ", 'onioneye'),
			          	"desc" => __("هر متنی می‌خواهید اینجا قرار دهید، برای مثال شماره تلفن یا ایمیل شما، که در بالا سمت راست نشان داده خواهد شد. " .
			          				 'توجه: شما می‌توانید از این برچسب‌های HTML استفاده کنید: a (href, title, class, id), br, em (class, id), strong (class, id), span (class, id), abbr (title), cite, code, strike.', 'onioneye'),
			          	"id" => "header_text",
			          	"std" => "",
			          	"type" => "textarea"); 
	
	$options[] = array( "name" => __("آدرس ایمیل", "onioneye"),
			          	"desc" => __("آدرس ایمیل خود را وارد کنید، که ایمیل‌های فرستاده شده توسط فرم تماس به آن ارسال خواهد شد. اگر نمی‌خواهید " . 
			          			     "این قسمت را خالی رها کنید.", 'onioneye'),
			          	"id" => "email_address",
			          	"std" => "",
			          	"type" => "text");
	
	
	
	/*-----------------------------------------------------------------------------------*/
	/* Homepage Settings */
	/*-----------------------------------------------------------------------------------*/
		
	$options[] = array( "name" => __("Homepage Setting", 'onioneye'),
						"type" => "heading");
						
	$options[] = array( "name" => __("متن مقدمه سربرگ", 'onioneye'),
			          	"desc" => __("متن سرتیتر دلخواه را قرار دهید، که در زیر لوگو و فهرست نشان داده می‌شود. " .
			          				 "این قسما را اگر متن مقدمه دلخواه نمی‌خواهید خالی رها کنید. " .
			          				 'توجه: شما می‌توانید از این برچسب‌های HTML استفاده کنید: a (href, title, class, id), br, em (class, id), strong (class, id), span (class, id), abbr (title), cite, code, strike.', 'onioneye'),
			          	"id" => "intro_text",
			          	"std" => "",
			          	"type" => "textarea"); 
	
	$options[] = array( "name" => __("تعداد آخرین پروزه‌ها در هر ردیف", 'onioneye'),
			          	"desc" => __("تعداد پروژه‌های که می‌خواهید در هر ردیف در قسمت نمونه‌کاها نمایش داده شود انتخاب کنید.", 'onioneye'),
			          	"id" => "number_of_featured_projects_per_row",
			          	"std" => 3,
			          	"type" => "radio",
			          	"options" => array(2 => __("دو", 'onioneye'), 3 => __("سه", 'onioneye'), 4 => __("چهار", 'onioneye')));
						
	$options[] = array( "name" => __("تعداد ردیف‌های آخرین پروژه‌ها", 'onioneye'),
			          	"desc" => __("تعداد ردیف‌های آخرین پروژه‌ها که می‌خواهید در قسمت نمونه‌کارها نشان داده شود انتخاب کنید.", 'onioneye'),
			          	"id" => "number_of_featured_project_rows",
			          	"std" => 3,
			          	"type" => "radio",
			          	"options" => array(1 => __("یک", 'onioneye'), 2 => __("دو", 'onioneye'), 3 => __("سه", 'onioneye')));
			          	
	$options[] = array( "name" => __("پیوند برگه‌ی نمونه‌کارها", 'onioneye'),
			          	"desc" => __("برگه‌ی نمونه‌کارها که همه‌ی آیتم‌های نمونه‌کارها را نمایش می‌دهد انتخاب کنید.", 'onioneye'),
			          	"id" => "portfolio_link",
			          	"std" => "انتخاب یک برگه:",
			          	"type" => "select",
			          	"options" => $options_pages);
						
	$options[] = array( "name" => __("فعال کردن قسمت آخرین مطالب", 'onioneye'),
			          	"desc" => __("این قسمت را برای نمایش آخرین مطالب در صفحه‌اصلی تیک بزنید.", 'onioneye'),
			          	"id" => "latest_articles_enabled",
			          	"std" => "0",
			          	"type" => "checkbox");
						
						
						
	/*-----------------------------------------------------------------------------------*/
	/* Blog Settings */
	/*-----------------------------------------------------------------------------------*/
		
	$options[] = array( "name" => __("Blog Settings", 'onioneye'),
						"type" => "heading");
	
	$options[] = array( "name" => __("نمایش کالم نوشته‌های وباگ یا نمایش چکیده؟", 'onioneye'),
	          			"desc" => __(" " .
	          			   			 "", 'onioneye'),
	          			"id" => "post_type",
	          			"std" => "excerpt",
	          			"type" => "radio",
	          			"options" => array("full" => __("نوشته کامل", 'onioneye'), "excerpt" => __("نوشته چکیده", 'onioneye'))); 
						
	$options[] = array( "name" => __("غیرفعال کردن ستون کناری در صفحه وبلاگ؟", 'onioneye'),
			          	"desc" => __("این گزینه را برای غیرفعال کردن ستون کناری در صفحه وبلاگ تیک بزنید.", 'onioneye'),
			          	"id" => "blog_page_sidebar_disabled",
			          	"std" => "0",
			          	"type" => "checkbox");
          
	$options[] = array( "name" => __("غیرفعال کردن ستون کناری در نوشته تکی وبلاگ؟", 'onioneye'),
			          	"desc" => __("این گزینه را برای غیرفعال کردن نوشته تکی وبلاگ تیک بزنید.", 'onioneye'),
			          	"id" => "single_post_sidebar_disabled",
			          	"std" => "0",
			          	"type" => "checkbox");
					
					
															
	/*-----------------------------------------------------------------------------------*/
	/* Styling Settings */
	/*-----------------------------------------------------------------------------------*/
	
	$options[] = array( "name" => "Styling Options",
						"type" => "heading");
						
	$options[] = array( "name" => __("تصویر/پترن پس‌زمینه", 'onioneye'),
			          	"desc" => __("پترن پس‌زمینه پوسته خود را انتخاب کنید.", 'onioneye'),
			          	"id" => "alt_pattern",
			          	"std" => "scan-lines.png",
			          	"type" => "select",
			          	"options" => $bg_patterns);
						
	$options[] = array( "name" => __("تصویر بدنه پس‌زمینه", 'onioneye'),
						"desc" => __("رنگ و تصویر پس‌زمینه را تغییر دهید. توجه: اگر در این قسمت یک تصویر پس‌زمینه برگزینید، به جای پترن انتخاب شده در گزینه بالا قرار می‌گیرد", 'onioneye'),
						"id" => "body_bg",
						"std" => $background_defaults, 
						"type" => "background");
						
	$options[] = array( "name" => "طرح‌بندی اصلی",
						"desc" => "مکان ستون کناری و محتوی اصلی را انتخاب کنید.",
						"id" => "sidebar_alignment",
						"std" => "two-cols-right-fixed",
						"type" => "images",
						"options" => array(
							'two-cols-right-fixed' => $imagepath . '2cr.png',
							'two-cols-left-fixed' => $imagepath . '2cl.png')
						);
	
	
	
	/*-----------------------------------------------------------------------------------*/
	/* Homepage Slider options */
	/*-----------------------------------------------------------------------------------*/
							        
	$options[] = array( "name" => __("Homepage Slider", 'onioneye'),
	          			"type" => "heading"); 
	          
	$options[] = array( "name" => __("غیرفعال کردن اسلایدر صفحه‌اصلی؟", 'onioneye'),
			          	"desc" => __("این گزینه را اگر می‌خواهید اسلایدر را غیرفعال کنید تیک بزنید.", 'onioneye'),
			          	"id" => "slider_disabled",
			          	"std" => "0",
			          	"type" => "checkbox");
	
	$options[] = array( "name" => __("نوع اسلایدر", 'onioneye'),
	          			"desc" => __("این گزینه نوع اسلایدری را که در صفحه‌اصلی استفاده می‌شود کنترل می‌کند. با انتخاب گزینه اول &ldquo;محو شونده&rdquo; " .
	          			 			 "اسلایدر صفحه‌اصلی شما فریم به فریم محو می‌شود. با انتخاب گزینه دوم &ldquo;تب&rdquo; اسلایدر صفحه‌اصلی شما فریم به فریم به صورت تب منتقل می‌شود.", 'onioneye'),
	          			"id" => "slider_type",
	          			"std" => "fade",
	          			"type" => "radio",
	          			"options" => array("fade" => __("محو شونده", 'onioneye'), "slide" => __("تب", 'onioneye'))); 
			  
	$options[] = array( "name" => __("ارتفاع اسلایدر", 'onioneye'),
			          	"desc" => __("ارتفاع اسلایدر را در پیکسل تنظیم کنید. بیش‌ترین مقدار برای ارتفاع 1000 و کم‌ترین 100 پیکسل است.", 'onioneye'),
			          	"id" => "slider_height",
			          	"std" => "450",
			          	"type" => "number"); 
						
	$options[] = array( "name" => __("اسلایدشو خودکار", 'onioneye'),
			          	"desc" => __("شروع خودکار اسلایدشود، یک عد مثبت (هرچیزی به‌جز صفر) به‌درستی تنظیم خواهد شد و زمان بین انیمیشن اسلاید در میلی ثانیه خواهد بود (1 ثانیه = 1000 میلی‌ثانیه).", 'onioneye'),
			          	"id" => "transition_speed",
			          	"std" => "5000",
			          	"type" => "number"); 
			  
	$options[] = array( "name" => __("توفق اسلایدر", 'onioneye'),
			          	"desc" => __("توقف اسلایدشو با کلیک روی بعدی/قبلی. یک عدد مثبت تنظیم خواهد شد و زمان توقف در میلی‌ثانیه خواهد بود، صفر توقف را لغو می‌کند.", 'onioneye'),
			          	"id" => "slider_pause",
			          	"std" => "2500",
			          	"type" => "number");  
			  
	$options[] = array( "name" => __("توقف شناور", 'onioneye'),
			          	"desc" => __("با نشانه‌گیری با موس اسلایدشو متوفق خواهد شد.", 'onioneye'),
			          	"id" => "pause_enabled",
			          	"std" => "1",
			          	"type" => "checkbox");  
			  
	$options[] = array( "name" => __("غیرفعال کردن تعویض کننده اسلایدر؟", 'onioneye'),
			          	"desc" => __("برای غیرفعال کردن دکمه‌های بعدی/قبلی تیک بزنید.", 'onioneye'),
			          	"id" => "disable_pagination",
			          	"std" => "0",
			          	"type" => "checkbox"); 
	          
	$options[] = array( "name" => __("تصادفی‌سازی اسلایدر؟", 'onioneye'),
			          	"desc" => __("برای تصادفی‌‌سازی اسلایدها در اسلایدشو تیک بزنید.", 'onioneye'),
			          	"id" => "randomize",
			          	"std" => "0",
			          	"type" => "checkbox"); 
	          
	$options[] = array( "name" => __("سرعت محو شدن اسلایدر", 'onioneye'),
			         	"desc" => __("سرعت انیمیشن محو شدن را در میلی‌ثانی تنظیم کنید.", 'onioneye'),
			          	"id" => "fade_speed",
			          	"std" => "350",
			          	"type" => "number");
	          
	$options[] = array( "name" => __("سرعت اسلاید اسلایدر", 'onioneye'),
			          	"desc" => __("سرعت انیمیشن اسلایدر را در میلی‌ثانی تنظیم کنید.", 'onioneye'),
			          	"id" => "slide_speed",
			          	"std" => "350",
			          	"type" => "number");
			  
	$options[] = array( "name" => __("تنظیم خودکار ارتفاع؟", 'onioneye'),
	          			"desc" => __("برای تنظیم خودکار ارتفاع در هر اسلایدر که نشان داده می‌شود تیک بزنید. " .
	          						 "ارتفاع محتوی در هر اسلاید ارتفاع اسلایدر خواهد بود.", 'onioneye'),
	          			"id" => "auto_height_enabled",
			          	"std" => "0",
			          	"type" => "checkbox"); 
			  
	$options[] = array( "name" => __("سرعت ارتفاع خودکار", 'onioneye'),
			          	"desc" => __("سرعت انیمیشن ارتفاع خودکار را در میلی‌ثانیه تنظیم کنید.", 'onioneye'),
			          	"id" => "auto_height_speed",
			          	"std" => "350",
			          	"type" => "number");
	
	
	
	/*-----------------------------------------------------------------------------------*/
	/* Portfolio Slider options */
	/*-----------------------------------------------------------------------------------*/
							        
	$options[] = array( "name" => __("Portfolio Slider", 'onioneye'),
	          			"type" => "heading"); 
	
	$options[] = array( "name" => __("نوع اسلایدر", 'onioneye'),
	          			"desc" => __("این گزینه نوع اسلایدری را که در صفحه‌اصلی استفاده می‌شود کنترل می‌کند. با انتخاب گزینه اول &ldquo;محو شونده&rdquo; " .
	          			 			 "اسلایدر صفحه‌اصلی شما فریم به فریم محو می‌شود. با انتخاب گزینه دوم &ldquo;تب&rdquo; اسلایدر صفحه‌اصلی شما فریم به فریم به صورت تب منتقل می‌شود.", 'onioneye'),
	          			"id" => "pf_slider_type",
	          			"std" => "slide",
	          			"type" => "radio",
	          			"options" => array("fade" => __("محو شدن", 'onioneye'), "slide" => __("تب", 'onioneye'))); 
						
	$options[] = array( "name" => __("اسلایدشو خودکار", 'onioneye'),
			          	"desc" => __("شروع خودکار اسلایدشود، یک عد مثبت (هرچیزی به‌جز صفر) به‌درستی تنظیم خواهد شد و زمان بین انیمیشن اسلاید در میلی ثانیه خواهد بود (1 ثانیه = 1000 میلی‌ثانیه).", 'onioneye'),
			          	"id" => "pf_transition_speed",
			          	"std" => "0",
			          	"type" => "number"); 
			  
	$options[] = array( "name" => __("توقف اسلایدر", 'onioneye'),
			          	"desc" => __("توقف اسلایدشو با کلیک روی بعدی/قبلی. یک عدد مثبت تنظیم خواهد شد و زمان توقف در میلی‌ثانیه خواهد بود، صفر توقف را لغو می‌کند.", 'onioneye'),
			          	"id" => "pf_slider_pause",
			          	"std" => "2500",
			          	"type" => "number");  
			  
	$options[] = array( "name" => __("توقف شناور", 'onioneye'),
			          	"desc" => __("با نشانه‌گیری با موس اسلایدشو متوفق خواهد شد.", 'onioneye'),
			          	"id" => "pf_pause_enabled",
			          	"std" => "1",
			          	"type" => "checkbox");  
			  
	$options[] = array( "name" => __("غیرفعال کردن تعویض کننده اسلایدر؟", 'onioneye'),
			          	"desc" => __("برای غیرفعال کردن دکمه‌های بعدی/قبلی تیک بزنید.", 'onioneye'),
			          	"id" => "pf_disable_pagination",
			          	"std" => "0",
			          	"type" => "checkbox"); 
	          
	$options[] = array( "name" => __("تصادفی‌سازی اسلایدر؟", 'onioneye'),
			          	"desc" => __("برای تصادفی‌‌سازی اسلایدها در اسلایدشو تیک بزنید.", 'onioneye'),
			          	"id" => "pf_randomize",
			          	"std" => "0",
			          	"type" => "checkbox"); 
	          
	$options[] = array( "name" => __("سرعت محو شدن اسلایدر", 'onioneye'),
			         	"desc" => __("سرعت انیمیشن محو شدن را در میلی‌ثانی تنظیم کنید.", 'onioneye'),
			          	"id" => "pf_fade_speed",
			          	"std" => "350",
			          	"type" => "number");
	          
	$options[] = array( "name" => __("سرعت اسلاید اسلایدر", 'onioneye'),
			          	"desc" => __("سرعت انیمیشن اسلایدر را در میلی‌ثانی تنظیم کنید.", 'onioneye'),
			          	"id" => "pf_slide_speed",
			          	"std" => "350",
			          	"type" => "number");
			  
	$options[] = array( "name" => __("سرعت ارتفاع خودکار", 'onioneye'),
			          	"desc" => __("سرعت انیمیشن ارتفاع خودکار را در میلی‌ثانیه تنظیم کنید.", 'onioneye'),
			          	"id" => "pf_auto_height_speed",
			          	"std" => "350",
			          	"type" => "number");
			
			
	
	/*-----------------------------------------------------------------------------------*/
	/* Lightbox options */
	/*-----------------------------------------------------------------------------------*/	      
	    
	$options[] = array( "name" => __("Lightbox", 'onioneye'),
	          			"type" => "heading"); 
						
	$options[] = array( "name" => __("فعال کردن Lightbox?", 'onioneye'),
			          	"desc" => __("برای فعال کردن lightbox تیک بزنید. اگر نقشه‌ای دارید، یا قبلا تعدا محتوی پیکربندی کرده‌اید، مانند تصویر، برای کار با لایت‌باکس، باید آن را فعال کنید.", 'onioneye'),
			          	"id" => "lightbox_enabled",
			          	"std" => "0",
			          	"type" => "checkbox");
					  
	$options[] = array( "name" => __("سرعت انیمیشن", 'onioneye'),
			          	"desc" => __("سرعت انیمیشن لایت‌باکس را تنظیم کنید.", 'onioneye'),
			          	"id" => "pp_animation_speed",
			          	"std" => "fast",
			          	"type" => "radio",
			          	"options" => array("fast" => __("سریع", 'onioneye'), "slow" => __("آهسته", 'onioneye'), "normal" => __("معمولی", 'onioneye')));
			  
	$options[] = array( "name" => __("فعال کردن اسلایدشو؟", 'onioneye'),
			          	"desc" => __("برای فعال کردن اسلایدشو لایت‌باکس تیک بزنید.", 'onioneye'),
			          	"id" => "pp_slideshow_enabled",
			          	"std" => "0",
			          	"type" => "checkbox");
	
	$options[] = array( "name" => __("سرعت اسلایدشو", 'onioneye'),
			          	"desc" => __("سرعت اسلایدشو را در میلی‌ثانیه تنظیم کنید (1 ثانیه = 1000 میلی‌ثانیه).", 'onioneye'),
			          	"id" => "pp_slideshow_speed",
			          	"std" => "1500",
			          	"type" => "number"); 
			  
	$options[] = array( "name" => __("اسلایدشو خودکار؟", 'onioneye'),
			          	"desc" => __("برای شروع خودکار اسلایدشو تیک بزنید.", 'onioneye'),
			          	"id" => "pp_autoplay_slideshow",
			          	"std" => "0",
			          	"type" => "checkbox"); 
	          
	$options[] = array( "name" => __("نمایش عنوان‌ها؟", 'onioneye'),
			          	"desc" => __("برای نمایش عنوان‌های اسلایدشوی تصویر و ویدئو تیک بزنید.", 'onioneye'),
			          	"id" => "pp_titles_shown",
			          	"std" => "0",
			          	"type" => "checkbox");  
	          
	$options[] = array( "name" => __("اجازه دادن به تغییر اندازه؟", 'onioneye'),
			          	"desc" => __("برای تغییر اندازه تصاویر بزگ تیک بزنید.", 'onioneye'),
			          	"id" => "pp_resize_allowed",
			          	"std" => "1",
			          	"type" => "checkbox");  
			  
	$options[] = array( "name" => __("عرض پیفرض", 'onioneye'),
			          	"desc" => __("عرض پیشفرض لایت‌باکس را در پیکسل تنظیم کنید.", 'onioneye'),
			          	"id" => "pp_default_width",
			          	"std" => "500",
			          	"type" => "number");
	          
	$options[] = array( "name" => __("ارتفاع پیشفرض", 'onioneye'),
			          	"desc" => __("ارتفاع پیشفرض لایت‌باکس را در پیکسل تنظیم کنید.", 'onioneye'),
			          	"id" => "pp_default_height",
			          	"std" => "344",
			          	"type" => "number");  
	          
	$options[] = array( "name" => __("پوسته Pretty Photo", 'onioneye'),
			          	"desc" => __("پوسته لایت‌باکس را تنظیم کنید.", 'onioneye'),
			          	"id" => "pp_theme",
			          	"std" => "pp_default",
			          	"type" => "radio",
			          	"options" => array("pp_default" => __("پیشفرض", 'onioneye'), "dark_rounded" => __("گرد تیره", 'onioneye'), 
			          					   "light_rounded" => __("گرد روشن", 'onioneye'), "light_square" => __("مربعی روشن", 'onioneye'), 
			          					   "dark_square" => __("مربعی تیره", 'onioneye'), "facebook" => "فیسبوک"));
			  
	$options[] = array( "name" => __("پخش خودکار ویدئوها؟", 'onioneye'),
			          	"desc" => __("برای پخش خودکار ویدئوها، هنگام باز کردن لایت‌باکس تیک بزنید.", 'onioneye'),
			          	"id" => "pp_autoplay_videos",
			          	"std" => "1",
			          	"type" => "checkbox");  
			  
	$options[] = array( "name" => __("Modal", 'onioneye'),
			          	"desc" => __("اگر تیک بزنید، فقط دکمه بستن پنجره لایت‌باکس را خواهد بست.", 'onioneye'),
			         	"id" => "pp_modal",
			          	"std" => "0",
			          	"type" => "checkbox");
			  
	$options[] = array( "name" => __("پوشاندن گالری", 'onioneye'),
	          			"desc" => __("اگر تیک بزنید، یک گالری تصویر تمام صفحه را با نشانه رفتن موس می‌پوشاند.", 'onioneye'),
	          			"id" => "pp_overlay_gallery",
	          			"std" => "1",
	          			"type" => "checkbox");  
	          			
	$options[] = array( "name" => __("غریفعال کردن پیوندهای شبکه‌های اجتماعی؟", 'onioneye'),
	          			"desc" => __("اگر تیک بزنید، پیوندهای شبکه‌های اجتماعی نظیر فیسبوک و توئیتر در لایت‌باکس غیرفعال خواهند شد.", 'onioneye'),
	          			"id" => "pp_sociables",
	          			"std" => "1",
	          			"type" => "checkbox");     
	          
	
	          
	/*-----------------------------------------------------------------------------------*/
	/* Sociables options */
	/*-----------------------------------------------------------------------------------*/	
	
	$options[] = array( "name" => __("Social Networking", 'onioneye'),
	          			"type" => "heading"); 
	          
	$options[] = array( "name" => __("آدرس Twitter", 'onioneye'),
			          	"desc" => __("آدرس Twitter خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "twitter_url",
			          	"std" => "",
			          	"type" => "text"); 
	          
	$options[] = array( "name" => __("آدرس Facebook", 'onioneye'),
			          	"desc" => __("آدرس Facebook خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "facebook_url",
			          	"std" => "",
			          	"type" => "text"); 
	          
	$options[] = array( "name" => __("آدرس Flickr", 'onioneye'),
			          	"desc" => __("آدرس Facebook خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "flickr_url",
			          	"std" => "",
			          	"type" => "text"); 
						
	$options[] = array( "name" => __("آدرس Vimeo", 'onioneye'),
			          	"desc" => __("آدرس Vimeo خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "vimeo_url",
			          	"std" => "",
			          	"type" => "text");
						
	$options[] = array( "name" => __("آدرس YouTube", 'onioneye'),
			          	"desc" => __("آدرس YouTube خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "youtube_url",
			          	"std" => "",
			          	"type" => "text");
			          	
	$options[] = array( "name" => __("آدرس LinkedIn", 'onioneye'),
			          	"desc" => __("آدرس LinkedIn خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "linkedin_url",
			          	"std" => "",
			          	"type" => "text");
			          	
	$options[] = array( "name" => __("آدرس Google+", 'onioneye'),
			          	"desc" => __("آدرس Google+ خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "googleplus_url",
			          	"std" => "",
			          	"type" => "text");
						
	$options[] = array( "name" => __("آدرس Dribbble", 'onioneye'),
			          	"desc" => __("آدرس Dribbble خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "dribbble_url",
			          	"std" => "",
			          	"type" => "text"); 
						
	$options[] = array( "name" => __("آدرس Tumblr", 'onioneye'),
			          	"desc" => __("آدرس Tumblr خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "tumblr_url",
			          	"std" => "",
			          	"type" => "text");
						
	$options[] = array( "name" => __("آدرس Skype", 'onioneye'),
			          	"desc" => __("آدرس Skype خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "skype_url",
			          	"std" => "",
			          	"type" => "text");
						
	$options[] = array( "name" => __("آدرس Delicious", 'onioneye'),
			          	"desc" => __("آدرس Delicious خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "delicious_url",
			          	"std" => "",
			          	"type" => "text"); 
						
	$options[] = array( "name" => __("آدرس Digg", 'onioneye'),
			          	"desc" => __("آدرس Digg خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "digg_url",
			          	"std" => "",
			          	"type" => "text");
	          
	$options[] = array( "name" => __("آدرس Feedburner RSS", 'onioneye'),
			          	"desc" => __("آدرس Feedburner خود را اینجا وارد کنید.", 'onioneye'),
			          	"id" => "rss_url",
			          	"std" => "",
			          	"type" => "text"); 
	            
	
	            
	/*-----------------------------------------------------------------------------------*/
	/* Footer options */
	/*-----------------------------------------------------------------------------------*/	
	
	$options[] = array( "name" => __("Footer", 'onioneye'),
	          			"type" => "heading"); 
	          
	$options[] = array( "name" => __("طرح بندی ستون پانوشت", 'onioneye'),
			          	"desc" => __("تعداد مکان‌های ستون‌/ابزارک‌های پانوشت را انتخاب کنید. مکان‌های ابزارک پانوشت Bottom 1, Bottom 2, Bottom 3, and Bottom 4 نام دارند " .
					  			   	 ". از راست به چپ مرتب شده‌اند، با Bottom 1 از  مکان راست شروع می‌شود و  Bottom 4 در چپ‌ترین مکان ابزارک قرار دارد. " .
					  			   	 "اگر برای مقال دو ستون را انتخاب کنید، Bottom 1 و Bottom 2 نمایش داده می‌شوند درحالی که Bottom 3 و Bottom 4 نادیده گرفته خواهند شد.", 'onioneye'),
			          	"id" => "footer_columns",
			          	"std" => 4,
			          	"type" => "radio",
			          	"options" => array(1 => __("یک", 'onioneye'), 2 => __("دو", 'onioneye'), 3 => __("سه", 'onioneye'), 4 => __("چهار", 'onioneye'))); 
	 
	$options[] = array( "name" => __("غیرفعال کردن ابزارک‌های پانوشت؟", 'onioneye'),
			          	"desc" => __("این گزینه را اگر مایلید ابزارک‌های پانوشت را غیرفعال کنید تیک بزنید. این مکان‌های ابزارک پانوشت را از هر صفحه کاملا پاک خواهد کرد.", 'onioneye'),
			          	"id" => "footer_widgets_disabled",
			          	"std" => "0",
			          	"type" => "checkbox");
	          
	$options[] = array( "name" => __("متن کپی‌رایت پانوشت", 'onioneye'),
			          	"desc" => __("هر متنی اینجا وارد کنید در قسمت کپی‌رایت پانوشت نمایش داده می‌شود.", 'onioneye'),
			          	"id" => "copyright_text",
			          	"std" => "&copy; " . date("Y") . ' ' . get_bloginfo('name') . ". تمامی حقوق محفوظ است.",
			          	"type" => "textarea");
		
	return $options;
	
	
}